@@ -5,6 +5,7 @@ import asyncio
 import async_timeout
 import json
 import logging
+import datetime
 
 AUTHENTICATION_ENDPOINT = "https://apis.control4.com/authentication/v1/rest"
 CONTROLLER_AUTHORIZATION_ENDPOINT = (
@@ -20,7 +21,6 @@ class C4Account:
     def __init__(self, username, password):
         self.username = username
         self.password = password
-        asyncio.run(self.getAccountBearerToken())
 
     async def __sendAccountAuthRequest(self):
         """Used internally to retrieve an account bearer token. Returns the entire JSON response from the Control4 auth API.
@@ -114,6 +114,7 @@ class C4Account:
         jsonDictionary = json.loads(data)
         try:
             self.account_bearer_token = jsonDictionary["authToken"]["token"]
+            return self.account_bearer_token
         except KeyError:
             msg = "Did not recieve an account bearer token. Is your username/password correct? "
             _LOGGER.error(msg + data)
@@ -186,7 +187,7 @@ class C4Account:
         return jsonDictionary
 
     async def getDirectorBearerToken(self, controller_common_name):
-        """Returns a director bearer token for making Control4 Director API requests.
+        """Returns a dictionary with a director bearer token for making Control4 Director API requests, and its expiry time (generally 86400 seconds after current time)
 
         Parameters:
             `account_bearer_token` - Control4 account bearer token.
@@ -195,4 +196,11 @@ class C4Account:
         """
         data = await self.__sendControllerAuthRequest(controller_common_name)
         jsonDictionary = json.loads(data)
-        return jsonDictionary["authToken"]["token"]
+        token_expiration = datetime.datetime.now() + datetime.timedelta(
+            seconds=jsonDictionary["authToken"]["validSeconds"]
+        )
+        return {
+            "token": jsonDictionary["authToken"]["token"],
+            "token_expiration": token_expiration,
+        }
+
